@@ -215,7 +215,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
                     self._exec(f"{install_exe} lib install FastLED")
                     self._exec(f"{install_exe} lib install TinyGPSPlus-ESP32")
                     self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/M5Core2.git")
-                    self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENV.git")
+                    self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/M5Unit-ENV.git")
                     self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENCODER.git")
                     self._exec(f"{install_exe} lib install --git-url https://github.com/aws-samples/arduino-aws-greengrass-iot.git")
                     self._exec(f"{install_exe} lib install --git-url https://github.com/awslabs/simpleiot-arduino.git")
@@ -255,7 +255,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
                 self._exec(f"{install_exe} lib install FastLED")
                 self._exec(f"{install_exe} lib install TinyGPSPlus-ESP32")
                 self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/M5Core2.git")
-                self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENV.git")
+                self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/M5Unit-ENV.git")
                 self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENCODER.git")
                 self._exec(f"{install_exe} lib install --git-url https://github.com/aws-samples/arduino-aws-greengrass-iot.git")
                 self._exec(f"{install_exe} lib install --git-url https://github.com/awslabs/simpleiot-arduino.git")
@@ -338,7 +338,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
                         print(f" + Exec: {cmd}")
                     self._exec(cmd)
 
-                    cmd = f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENV.git"
+                    cmd = f"{install_exe} lib install --git-url https://github.com/m5stack/M5Unit-ENV.git"
                     if verbose:
                         print(f" + Exec: {cmd}")
                     self._exec(cmd)
